# FeaturEng

_created by Austin Poor_

[![PyPI](https://img.shields.io/pypi/v/featureng)](https://pypi.org/project/featureng)
[![](https://github.com/a-poor/featureng/workflows/Python%20package/badge.svg)](https://github.com/a-poor/featureng/actions)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/featureng)](https://pypi.org/project/featureng)
[![GitHub](https://img.shields.io/github/license/a-poor/featureng)](https://github.com/a-poor/featureng/blob/main/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/featureng/badge/?version=latest)](https://featureng.readthedocs.io/en/latest/?badge=latest)

`featureng` (pronounced _featur-ing_) is a library for feature engineering.

I wanted to create a library to store tools to help in the feature engineering
process – by extracting information from existing data or by simplifying the
process of adding in external data.

* GitHub: https://github.com/a-poor/featureng
* PyPi: https://pypi.org/project/featureng
* Read the Docs: https://featureng.readthedocs.io
